import json
import os
import boto3


get_bucket_name_from_arn = lambda arn: arn[13:] if arn is not None else None
BUCKET_NAME = get_bucket_name_from_arn(os.getenv("RESULTS_BUCKET_NAME", None))

def write_result_to_s3(result: dict, key: str) -> None:
    s3 = boto3.client('s3')
    object_key = key

    response = s3.put_object(
        Body=json.dumps(result),
        Bucket=BUCKET_NAME,
        Key=object_key
    )
    return response


from cs_ai_common.logging.internal_logger import InternalLogger
import boto3
from botocore.exceptions import ClientError


def update_task_status_failed(task_id: str, table_name: str) -> None:
    dynamodb = boto3.client('dynamodb')
    
    try:
        dynamodb.update_item(
            TableName=table_name,
            Key={
                'task_id': {
                    'S': task_id
                }
            },
            UpdateExpression="set #status = :status",
            ExpressionAttributeNames={
                "#status": "status"
            },
            ExpressionAttributeValues={
                ":status": {
                    'S': "FAILED"
                }
            }
        )
        InternalLogger.LogDebug("UpdateItem succeeded")
    except ClientError as e:
        InternalLogger.LogError(f"Unable to update item: {e.response['Error']['Message']}")
        raise e


from typing import List, Optional
from pydantic import BaseModel

class ResolverResponse(BaseModel): 
    Price: Optional[str] = None
    PriceCurrency: Optional[str] = None
    Mileage: Optional[str] = None
    ProductionYear: Optional[str] = None
    FuelType: Optional[str] = None
    Transmision: Optional[str] = None
    HorsePower: Optional[str] = None
    Capacity: Optional[str] = None
    AdvertisementLink: Optional[str] = None
    Thumbnails: Optional[List[str]] = None
    Source: Optional[str] = None